==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QTemporaryFile_shell.h <==
#ifndef QTEMPORARYFILE_SHELL_H
#define QTEMPORARYFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCore/qtemporaryfile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qfile.h>
#include <QtCore/qfiledevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QTemporaryFile_shell : public QTemporaryFile, public QtJambiShellInterface
{
public:
    QTemporaryFile_shell();
    QTemporaryFile_shell(QObject* parent0);
    QTemporaryFile_shell(const QString& templateName0);
    QTemporaryFile_shell(const QString& templateName0, QObject* parent1);
    ~QTemporaryFile_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode flags0) override;
    QFileDevice::Permissions permissions() const override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool resize(qint64 sz0) override;
    bool seek(qint64 offset0) override;
    bool setPermissions(QFileDevice::Permissions permissionSpec0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTemporaryFile_access : public QTemporaryFile
{
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint flags0);
};

#endif // QTEMPORARYFILE_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QTemporaryFile_shell.h <==
#ifndef QTEMPORARYFILE_SHELL_H
#define QTEMPORARYFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qtemporaryfile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qfile.h>
#include <QtCore/qfiledevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QTemporaryFile_shell : public QTemporaryFile, public QtJambiShellInterface
{
public:
    QTemporaryFile_shell();
    QTemporaryFile_shell(QObject* parent0);
    QTemporaryFile_shell(const QString& templateName0);
    QTemporaryFile_shell(const QString& templateName0, QObject* parent1);
    ~QTemporaryFile_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QTemporaryFile_mshell;
    friend class QTemporaryFile_oshell;
};


class QTemporaryFile_mshell : public QTemporaryFile_shell
{
public:
    using QTemporaryFile_shell::QTemporaryFile_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QTemporaryFile_oshell : public QTemporaryFile_mshell
{
public:
    using QTemporaryFile_mshell::QTemporaryFile_mshell;
    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODeviceBase::OpenMode flags0) override;
    QFileDevice::Permissions permissions() const override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool resize(qint64 sz0) override;
    bool seek(qint64 offset0) override;
    bool setPermissions(QFileDevice::Permissions permissionSpec0) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTemporaryFile_access : public QTemporaryFile
{
    jboolean __qt_open_QIODeviceBase_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint flags0);
};

#endif // QTEMPORARYFILE_SHELL_H
